@@ -57,19 +57,19 @@ def test_deserialize():
 def test_serialize():
     v = gb.Vector.from_values([1], 2)
 
-    # unary_pickle = gb.operator.UnaryOp.register_new("unary_pickle", unarypickle)
-    # binary_pickle = gb.operator.BinaryOp.register_new("binary_pickle", binarypickle)
-    # monoid_pickle = gb.operator.Monoid.register_new("monoid_pickle", binary_pickle, 0)
-    # semiring_pickle = gb.operator.Semiring.register_new(
+    # unary_pickle = gb.core.operator.UnaryOp.register_new("unary_pickle", unarypickle)
+    # binary_pickle = gb.core.operator.BinaryOp.register_new("binary_pickle", binarypickle)
+    # monoid_pickle = gb.core.operator.Monoid.register_new("monoid_pickle", binary_pickle, 0)
+    # semiring_pickle = gb.core.operator.Semiring.register_new(
     #     "semiring_pickle", monoid_pickle, binary_pickle
     # )
 
-    unary_anon = gb.operator.UnaryOp.register_anonymous(unaryanon)
-    binary_anon = gb.operator.BinaryOp.register_anonymous(binaryanon)
-    indexunary_anon = gb.operator.IndexUnaryOp.register_anonymous(indexunaryanon)
-    select_anon = gb.operator.SelectOp.register_anonymous(indexunaryanon)
-    monoid_anon = gb.operator.Monoid.register_anonymous(binary_anon, 0)
-    semiring_anon = gb.operator.Semiring.register_anonymous(monoid_anon, binary_anon)
+    unary_anon = gb.core.operator.UnaryOp.register_anonymous(unaryanon)
+    binary_anon = gb.core.operator.BinaryOp.register_anonymous(binaryanon)
+    indexunary_anon = gb.core.operator.IndexUnaryOp.register_anonymous(indexunaryanon)
+    select_anon = gb.core.operator.SelectOp.register_anonymous(indexunaryanon)
+    monoid_anon = gb.core.operator.Monoid.register_anonymous(binary_anon, 0)
+    semiring_anon = gb.core.operator.Semiring.register_anonymous(monoid_anon, binary_anon)
     d = {
         "scalar": gb.Scalar.from_value(2),
         "empty_scalar": gb.Scalar(bool),
@@ -115,7 +115,7 @@ def test_serialize():
         "semiring_anon": semiring_anon,
         "dtypes.BOOL": gb.dtypes.BOOL,
         "dtypes._INDEX": gb.dtypes._INDEX,
-        "all_indices": gb.expr._ALL_INDICES,
+        "all_indices": gb.core.expr._ALL_INDICES,
         "replace": gb.replace,
     }
     try:
@@ -139,13 +139,13 @@ def check_values(d):
     assert d["vector"].isequal(v, check_dtype=True)
     assert d["matrix"].isequal(gb.Matrix.from_values([2], [3], 4), check_dtype=True)
     assert d["matrix.T"].isequal(gb.Matrix.from_values([3], [4], 5).T, check_dtype=True)
-    assert type(d["vector.S"]) is gb.mask.StructuralMask
+    assert type(d["vector.S"]) is gb.core.mask.StructuralMask
     assert d["vector.S"].parent.isequal(v, check_dtype=True)
-    assert type(d["vector.V"]) is gb.mask.ValueMask
+    assert type(d["vector.V"]) is gb.core.mask.ValueMask
     assert d["vector.V"].parent.isequal(v, check_dtype=True)
-    assert type(d["~vector.S"]) is gb.mask.ComplementedStructuralMask
+    assert type(d["~vector.S"]) is gb.core.mask.ComplementedStructuralMask
     assert d["~vector.S"].parent.isequal(v, check_dtype=True)
-    assert type(d["~vector.V"]) is gb.mask.ComplementedValueMask
+    assert type(d["~vector.V"]) is gb.core.mask.ComplementedValueMask
     assert d["~vector.V"].parent.isequal(v, check_dtype=True)
     assert d["unary.abs"] is gb.unary.abs
     assert d["binary.minus"] is gb.binary.minus
@@ -185,7 +185,7 @@ def check_values(d):
     d["semiring_anon"]
     assert d["dtypes.BOOL"] is gb.dtypes.BOOL
     assert d["dtypes._INDEX"] is gb.dtypes._INDEX
-    assert d["all_indices"] is gb.expr._ALL_INDICES
+    assert d["all_indices"] is gb.core.expr._ALL_INDICES
     assert d["replace"] is gb.replace
 
 
@@ -223,22 +223,22 @@ def identity_par(z):
 
 @pytest.mark.slow
 def test_serialize_parameterized():
-    # unary_pickle = gb.operator.UnaryOp.register_new(
+    # unary_pickle = gb.core.operator.UnaryOp.register_new(
     #     "unary_pickle_par", unarypickle_par, parameterized=True
     # )
-    # binary_pickle = gb.operator.BinaryOp.register_new(
+    # binary_pickle = gb.core.operator.BinaryOp.register_new(
     #     "binary_pickle_par", binarypickle_par, parameterized=True
     # )
-    # monoid_pickle = gb.operator.Monoid.register_new("monoid_pickle_par", binary_pickle, 0)
-    # semiring_pickle = gb.operator.Semiring.register_new(
+    # monoid_pickle = gb.core.operator.Monoid.register_new("monoid_pickle_par", binary_pickle, 0)
+    # semiring_pickle = gb.core.operator.Semiring.register_new(
     #     "semiring_pickle_par", monoid_pickle, binary_pickle
     # )
 
-    unary_anon = gb.operator.UnaryOp.register_anonymous(unaryanon_par, parameterized=True)
-    binary_anon = gb.operator.BinaryOp.register_anonymous(binaryanon_par, parameterized=True)
-    monoid_anon = gb.operator.Monoid.register_anonymous(binary_anon, 0)
-    monoid2_anon = gb.operator.Monoid.register_anonymous(binary_anon, identity_par)
-    semiring_anon = gb.operator.Semiring.register_anonymous(monoid_anon, binary_anon)
+    unary_anon = gb.core.operator.UnaryOp.register_anonymous(unaryanon_par, parameterized=True)
+    binary_anon = gb.core.operator.BinaryOp.register_anonymous(binaryanon_par, parameterized=True)
+    monoid_anon = gb.core.operator.Monoid.register_anonymous(binary_anon, 0)
+    monoid2_anon = gb.core.operator.Monoid.register_anonymous(binary_anon, identity_par)
+    semiring_anon = gb.core.operator.Semiring.register_anonymous(monoid_anon, binary_anon)
     d = {
         "binary.isclose(rel_tol=1., abs_tol=1.)": gb.binary.isclose(rel_tol=1.0, abs_tol=1.0),
         "unary_anon": unary_anon,
