@@ -1078,7 +1078,7 @@ def test_del(capsys):
     # v has `gb_obj` of NULL
     v = Vector.from_values([0, 1], [0, 1])
     gb_obj = v.gb_obj
-    v.gb_obj = graphblas.ffi.NULL
+    v.gb_obj = graphblas.core.NULL
     del v
     # let's clean up so we don't have a memory leak
     v2 = object.__new__(Vector)
@@ -1579,9 +1579,9 @@ def test_expr_is_like_vector(v):
     }
     assert attrs - expr_attrs == expected, (
         "If you see this message, you probably added a method to Vector.  You may need to "
-        "add an entry to `vector` or `matrix_vector` set in `graphblas._automethods.py` "
-        "and then run `python -m graphblas._automethods`.  If you're messing with infix "
-        "methods, then you may need to run `python -m graphblas._infixmethods`."
+        "add an entry to `vector` or `matrix_vector` set in `graphblas.core.automethods` "
+        "and then run `python -m graphblas.core.automethods`.  If you're messing with infix "
+        "methods, then you may need to run `python -m graphblas.core.infixmethods`."
     )
     assert attrs - infix_attrs == expected
 
@@ -1613,9 +1613,9 @@ def test_index_expr_is_like_vector(v):
     }
     assert attrs - expr_attrs == expected, (
         "If you see this message, you probably added a method to Vector.  You may need to "
-        "add an entry to `vector` or `matrix_vector` set in `graphblas._automethods.py` "
-        "and then run `python -m graphblas._automethods`.  If you're messing with infix "
-        "methods, then you may need to run `python -m graphblas._infixmethods`."
+        "add an entry to `vector` or `matrix_vector` set in `graphblas.core.automethods` "
+        "and then run `python -m graphblas.core.automethods`.  If you're messing with infix "
+        "methods, then you may need to run `python -m graphblas.core.infixmethods`."
     )
 
 
@@ -1972,6 +1972,8 @@ def test_udt():
     # arrays as dtypes!
     np_dtype = np.dtype("(3,)uint16")
     udt2 = dtypes.register_anonymous(np_dtype, "has_subdtype")
+    udt2alt = dtypes.register_anonymous("UINT16[3]")
+    assert udt2 == udt2alt
     s = Scalar(udt2)
     s.value = [0, 0, 0]
 
@@ -1990,6 +1992,12 @@ def test_udt():
     v[:] = 1
     w[:] = np.array([1, 1, 1], dtype=np.uint8)
     assert v.isequal(w)
+    v[:] = 0
+    v << 1
+    assert v.isequal(w)
+    v[:] = 0
+    v << (1, 1, 1)
+    assert v.isequal(w)
 
     indices, values = v.to_values()
     assert_array_equal(values, np.ones((2, 3), dtype=np.uint16))
@@ -2093,6 +2101,9 @@ def test_iteration(v):
     assert len(list(v.ss.iterkeys(2))) == 2
     assert len(list(v.ss.itervalues(N))) == 0
     assert len(list(v.ss.iteritems(N + 1))) == 0
+    assert next(v.ss.iterkeys()) in v
+    assert next(v.ss.itervalues()) is not None
+    assert next(v.ss.iteritems()) is not None
 
 
 def test_broadcasting(A, v):
