@@ -133,7 +133,7 @@ def __getattr__(name):
     if _config.get("mapnumpy") and name in _numpy_to_graphblas:
         globals()[name] = getattr(_unary, _numpy_to_graphblas[name])
     else:
-        from .. import operator
+        from ..core import operator
 
         numpy_func = getattr(_np, name)
 
@@ -143,7 +143,7 @@ def __getattr__(name):
         operator.UnaryOp.register_new(f"numpy.{name}", func)
         if name == "reciprocal":
             # numba doesn't match numpy here
-            def reciprocal(x):
+            def reciprocal(x):  # pragma: no cover
                 return 1 if x else 0
 
             op = operator.UnaryOp.register_anonymous(reciprocal)
